//
//  $Id$
//
// Copyright (c) 2003 Daniel J. Gregor, Jr.
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 
//    - Redistributions of source code must retain the above copyright
//      notice, this list of conditions and the following disclaimer.
//    - Redistributions in binary form must reproduce the above
//      copyright notice, this list of conditions and the following
//      disclaimer in the documentation and/or other materials provided
//      with the distribution.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
// FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
// COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
// BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
// ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
//

package com.gregor.mailping;

import java.io.*;
import java.net.*;
import java.util.*;

public class SMTPListener implements Runnable {
	protected String host;
	protected PrintStream log;

	protected ServerSocket s;

	public SMTPListener(String host, PrintStream log)
	{
		this.host = host;
		this.log = log;
	}

	public SMTPListener(String host)
	{
		this.host = host;
		this.log = System.out;
	}

	public void run() {
		try {
			doListener();
		} catch (UnknownHostException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	public void doListener()
		throws UnknownHostException, IOException
	{
		if (host == null || host.equals("*")) {
			s = new ServerSocket(25);
		} else {
			s = new ServerSocket(25, 0,
			    InetAddress.getByName(host));
		}

		System.err.println("Listener started");

		while (true) {
			new Thread(new SMTPServerSocket(s.accept(),
			    log)).start();
		}
	}

	public static void main(String argv[]) {
		String host;

		host = System.getProperty("smtplistener.ip", null);

		new Thread(new SMTPListener(host)).start();
	}
}
